==> myfaces-core-assembly-2.1.18-src.zip: myfaces-core-module-2.1.18/impl/src/main/java/org/apache/myfaces/view/facelets/tag/ui/ComponentRefHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.tag.ui;

import javax.faces.view.facelets.ComponentConfig;
import javax.faces.view.facelets.ComponentHandler;

import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFFaceletTag;
import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFFaceletTags;

/**
 * 
 */
@JSFFaceletTags(tags={
        @JSFFaceletTag(
                name="ui:component",
                componentClass="org.apache.myfaces.view.facelets.tag.ui._Component"),
        @JSFFaceletTag(
                name="ui:fragment",
                componentClass="org.apache.myfaces.view.facelets.tag.ui._Fragment")
})
public final class ComponentRefHandler extends ComponentHandler
{

    public final static String NAME = "component";

    public ComponentRefHandler(ComponentConfig config)
    {
        super(config);
    }

}

==> myfaces-core-assembly-3.0.3-src.zip: myfaces-core-module-3.0.3/impl/src/main/java/org/apache/myfaces/view/facelets/tag/ui/ComponentRefHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.tag.ui;

import jakarta.faces.view.facelets.ComponentConfig;
import jakarta.faces.view.facelets.ComponentHandler;

import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFFaceletTag;
import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFFaceletTags;

/**
 * 
 */
@JSFFaceletTags(tags={
        @JSFFaceletTag(
                name="ui:component",
                componentClass="org.apache.myfaces.view.facelets.tag.ui._Component"),
        @JSFFaceletTag(
                name="ui:fragment",
                componentClass="org.apache.myfaces.view.facelets.tag.ui._Fragment")
})
public final class ComponentRefHandler extends ComponentHandler
{

    public final static String NAME = "component";

    public ComponentRefHandler(ComponentConfig config)
    {
        super(config);
    }

}
